@@ -1,9 +1,10 @@
 import datetime
 import json
 import time
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Tuple, Union
 
-from moto.core import BackendDict, BaseBackend, BaseModel
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel
 from moto.core.utils import utcfromtimestamp, utcnow
 from moto.moto_api._internal import mock_random
 
@@ -11,6 +12,7 @@ from .exceptions import (
     ClientError,
     InvalidParameterException,
     InvalidRequestException,
+    OperationNotPermittedOnReplica,
     ResourceExistsException,
     ResourceNotFoundException,
     SecretHasNoValueException,
@@ -21,10 +23,27 @@ from .list_secrets.filters import (
     description_filter,
     filter_all,
     name_filter,
+    owning_service_filter,
     tag_key,
     tag_value,
 )
-from .utils import get_secret_name_from_partial_arn, random_password, secret_arn
+from .utils import (
+    SecretsManagerSecretIdentifier,
+    get_secret_name_from_partial_arn,
+    random_password,
+)
+
+MAX_RESULTS_DEFAULT = 100
+
+
+def filter_primary_region(
+    secret: Union["FakeSecret", "ReplicaSecret"], values: List[str]
+) -> bool:
+    if isinstance(secret, FakeSecret):
+        return len(secret.replicas) > 0 and secret.region in values
+    elif isinstance(secret, ReplicaSecret):
+        return secret.source.region in values
+
 
 _filter_functions = {
     "all": filter_all,
@@ -32,6 +51,8 @@ _filter_functions = {
     "description": description_filter,
     "tag-key": tag_key,
     "tag-value": tag_value,
+    "primary-region": filter_primary_region,
+    "owning-service": owning_service_filter,
 }
 
 
@@ -39,7 +60,9 @@ def filter_keys() -> List[str]:
     return list(_filter_functions.keys())
 
 
-def _matches(secret: "FakeSecret", filters: List[Dict[str, Any]]) -> bool:
+def _matches(
+    secret: Union["FakeSecret", "ReplicaSecret"], filters: List[Dict[str, Any]]
+) -> bool:
     is_match = True
 
     for f in filters:
@@ -50,12 +73,7 @@ def _matches(secret: "FakeSecret", filters: List[Dict[str, Any]]) -> bool:
     return is_match
 
 
-class SecretsManager(BaseModel):
-    def __init__(self, region_name: str):
-        self.region = region_name
-
-
-class FakeSecret:
+class FakeSecret(BaseModel):
     def __init__(
         self,
         account_id: str,
@@ -71,14 +89,20 @@ class FakeSecret:
         version_stages: Optional[List[str]] = None,
         last_changed_date: Optional[int] = None,
         created_date: Optional[int] = None,
+        replica_regions: Optional[List[Dict[str, str]]] = None,
+        force_overwrite: bool = False,
     ):
         self.secret_id = secret_id
         self.name = secret_id
-        self.arn = secret_arn(account_id, region_name, secret_id)
+        self.arn = SecretsManagerSecretIdentifier(
+            account_id, region_name, secret_id
+        ).generate(tags=tags)
+        self.account_id = account_id
+        self.region = region_name
         self.secret_string = secret_string
         self.secret_binary = secret_binary
         self.description = description
-        self.tags = tags or []
+        self.tags = tags or None
         self.kms_key_id = kms_key_id
         self.version_stages = version_stages
         self.last_changed_date = last_changed_date
@@ -100,6 +124,43 @@ class FakeSecret:
         else:
             self.set_default_version_id(None)
 
+        self.replicas = self.create_replicas(
+            replica_regions or [], force_overwrite=force_overwrite
+        )
+
+    @property
+    def owning_service(self) -> Optional[str]:
+        for tag in self.tags or []:
+            if tag["Key"] == "aws:secretsmanager:owningService":
+                return tag["Value"]
+        return None
+
+    def create_replicas(
+        self, replica_regions: List[Dict[str, str]], force_overwrite: bool
+    ) -> List["ReplicaSecret"]:
+        # Validate first, before we create anything
+        for replica_config in replica_regions or []:
+            if replica_config["Region"] == self.region:
+                raise InvalidParameterException("Invalid replica region.")
+
+        replicas: List[ReplicaSecret] = []
+        for replica_config in replica_regions or []:
+            replica_region = replica_config["Region"]
+            backend = secretsmanager_backends[self.account_id][replica_region]
+            if self.name in backend.secrets:
+                if force_overwrite:
+                    backend.secrets.pop(self.name)
+                    replica = ReplicaSecret(self, replica_region)
+                    backend.secrets[replica.arn] = replica
+                else:
+                    message = f"Replication failed: Secret name simple already exists in region {backend.region_name}."
+                    replica = ReplicaSecret(self, replica_region, "Failed", message)
+            else:
+                replica = ReplicaSecret(self, replica_region)
+                backend.secrets[replica.arn] = replica
+            replicas.append(replica)
+        return replicas
+
     def update(
         self,
         description: Optional[str] = None,
@@ -108,7 +169,7 @@ class FakeSecret:
         last_changed_date: Optional[int] = None,
     ) -> None:
         self.description = description
-        self.tags = tags or []
+        self.tags = tags or None
         if last_changed_date is not None:
             self.last_changed_date = last_changed_date
 
@@ -161,7 +222,7 @@ class FakeSecret:
     ) -> str:
         if not version_id:
             version_id = self.default_version_id
-        dct = {
+        dct: Dict[str, Any] = {
             "ARN": self.arn,
             "Name": self.name,
         }
@@ -169,6 +230,8 @@ class FakeSecret:
             dct["VersionId"] = version_id
         if version_id and include_version_stages:
             dct["VersionStages"] = self.versions[version_id]["version_stages"]
+        if self.replicas:
+            dct["ReplicationStatus"] = [replica.config for replica in self.replicas]
         return json.dumps(dct)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -177,14 +240,17 @@ class FakeSecret:
         dct: Dict[str, Any] = {
             "ARN": self.arn,
             "Name": self.name,
-            "KmsKeyId": self.kms_key_id,
             "LastChangedDate": self.last_changed_date,
             "LastAccessedDate": None,
             "NextRotationDate": self.next_rotation_date,
             "DeletedDate": self.deleted_date,
             "CreatedDate": self.created_date,
         }
-        if self.tags:
+        if self.kms_key_id != SecretsManagerBackend.DEFAULT_KMS_KEY_ALIAS:
+            dct["KmsKeyId"] = self.kms_key_id
+        if self.owning_service is not None:
+            dct["OwningService"] = self.owning_service
+        if self.tags is not None:
             dct["Tags"] = self.tags
         if self.description:
             dct["Description"] = self.description
@@ -208,6 +274,8 @@ class FakeSecret:
                     "LastRotatedDate": self.last_rotation_date,
                 }
             )
+        if self.replicas:
+            dct["ReplicationStatus"] = [replica.config for replica in self.replicas]
         return dct
 
     def _form_version_ids_to_stages(self) -> Dict[str, str]:
@@ -218,15 +286,74 @@ class FakeSecret:
         return version_id_to_stages
 
 
-class SecretsStore(Dict[str, FakeSecret]):
+class ReplicaSecret:
+    def __init__(
+        self,
+        source: FakeSecret,
+        region: str,
+        status: Optional[str] = None,
+        message: Optional[str] = None,
+    ):
+        self.source = source
+        self.arn = source.arn.replace(source.region, region)
+        self.region = region
+        self.status = status or "InSync"
+        self.message = message or "Replication succeeded"
+        self.has_replica = status is None
+        self.config = {
+            "Region": self.region,
+            "KmsKeyId": SecretsManagerBackend.DEFAULT_KMS_KEY_ALIAS,
+            "Status": self.status,
+            "StatusMessage": self.message,
+        }
+
+    def is_deleted(self) -> bool:
+        return False
+
+    def to_dict(self) -> Dict[str, Any]:
+        dct = self.source.to_dict()
+        dct["ARN"] = self.arn
+        dct["PrimaryRegion"] = self.source.region
+        return dct
+
+    @property
+    def default_version_id(self) -> Optional[str]:
+        return self.source.default_version_id
+
+    @property
+    def versions(self) -> Dict[str, Dict[str, Any]]:  # type: ignore[misc]
+        return self.source.versions
+
+    @property
+    def name(self) -> str:
+        return self.source.name
+
+    @property
+    def secret_id(self) -> str:
+        return self.source.secret_id
+
+    @property
+    def description(self) -> Optional[str]:
+        return self.source.description
+
+    @property
+    def tags(self) -> Optional[List[Dict[str, str]]]:
+        return self.source.tags
+
+    @property
+    def owning_service(self) -> Optional[str]:
+        return self.source.owning_service
+
+
+class SecretsStore(Dict[str, Union[FakeSecret, ReplicaSecret]]):
     # Parameters to this dictionary can be three possible values:
     # names, full ARNs, and partial ARNs
     # Every retrieval method should check which type of input it receives
 
-    def __setitem__(self, key: str, value: FakeSecret) -> None:
+    def __setitem__(self, key: str, value: Union[FakeSecret, ReplicaSecret]) -> None:
         super().__setitem__(key, value)
 
-    def __getitem__(self, key: str) -> FakeSecret:
+    def __getitem__(self, key: str) -> Union[FakeSecret, ReplicaSecret]:
         for secret in dict.values(self):
             if secret.arn == key or secret.name == key:
                 return secret
@@ -240,14 +367,14 @@ class SecretsStore(Dict[str, FakeSecret]):
         name = get_secret_name_from_partial_arn(key)
         return dict.__contains__(self, name)  # type: ignore
 
-    def get(self, key: str) -> Optional[FakeSecret]:  # type: ignore
+    def get(self, key: str) -> Optional[Union[FakeSecret, ReplicaSecret]]:  # type: ignore
         for secret in dict.values(self):
             if secret.arn == key or secret.name == key:
                 return secret
         name = get_secret_name_from_partial_arn(key)
         return super().get(name)
 
-    def pop(self, key: str) -> Optional[FakeSecret]:  # type: ignore
+    def pop(self, key: str) -> Optional[Union[FakeSecret, ReplicaSecret]]:  # type: ignore
         for secret in dict.values(self):
             if secret.arn == key or secret.name == key:
                 key = secret.name
@@ -256,19 +383,12 @@ class SecretsStore(Dict[str, FakeSecret]):
 
 
 class SecretsManagerBackend(BaseBackend):
+    DEFAULT_KMS_KEY_ALIAS = "alias/aws/secretsmanager"
+
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
         self.secrets = SecretsStore()
 
-    @staticmethod
-    def default_vpc_endpoint_service(
-        service_region: str, zones: List[str]
-    ) -> List[Dict[str, str]]:
-        """Default VPC endpoint services."""
-        return BaseBackend.default_vpc_endpoint_service_factory(
-            service_region, zones, "secretsmanager"
-        )
-
     def _is_valid_identifier(self, identifier: str) -> bool:
         return identifier in self.secrets
 
@@ -294,6 +414,8 @@ class SecretsManagerBackend(BaseBackend):
             raise SecretNotFoundException()
 
         secret = self.secrets[secret_id]
+        if isinstance(secret, ReplicaSecret):
+            raise OperationNotPermittedOnReplica
         if secret.is_deleted():
             raise InvalidRequestException(
                 "You tried to perform the operation on a secret that's currently marked deleted."
@@ -376,6 +498,53 @@ class SecretsManagerBackend(BaseBackend):
 
         return response_data
 
+    def batch_get_secret_value(
+        self,
+        secret_id_list: Optional[List[str]] = None,
+        filters: Optional[List[Dict[str, Any]]] = None,
+        max_results: Optional[int] = None,
+        next_token: Optional[str] = None,
+    ) -> Tuple[List[Dict[str, Any]], List[Any], Optional[str]]:
+        secret_list = []
+        errors: List[Any] = []
+        if secret_id_list and filters:
+            raise InvalidParameterException(
+                "Either 'SecretIdList' or 'Filters' must be provided, but not both."
+            )
+
+        if max_results and not filters:
+            raise InvalidParameterException(
+                "'Filters' not specified. 'Filters' must also be specified when 'MaxResults' is provided."
+            )
+
+        if secret_id_list:
+            for secret_id in secret_id_list:
+                # TODO perhaps there should be a check if the secret id is valid identifier
+                # and add an error to the list if not
+                try:
+                    # TODO investigate the behaviour when the secret doesn't exist or has been deleted,
+                    # might need to add an error to the list
+                    secret_list.append(self.get_secret_value(secret_id, "", ""))
+                except (SecretNotFoundException, InvalidRequestException):
+                    pass
+
+        if filters:
+            for secret in self.secrets.values():
+                if _matches(secret, filters):
+                    if isinstance(secret, FakeSecret):
+                        secret_list.append(
+                            self.get_secret_value(secret.secret_id, "", "")
+                        )
+                    elif isinstance(secret, ReplicaSecret):
+                        secret_list.append(
+                            self.get_secret_value(secret.source.secret_id, "", "")
+                        )
+
+        secret_page, new_next_token = self._get_secret_values_page_and_next_token(
+            secret_list, max_results, next_token
+        )
+        return secret_page, errors, new_next_token
+
     def update_secret(
         self,
         secret_id: str,
@@ -385,18 +554,20 @@ class SecretsManagerBackend(BaseBackend):
         kms_key_id: Optional[str] = None,
         description: Optional[str] = None,
     ) -> str:
-
         # error if secret does not exist
         if secret_id not in self.secrets:
             raise SecretNotFoundException()
 
-        if self.secrets[secret_id].is_deleted():
+        secret = self.secrets[secret_id]
+        if isinstance(secret, ReplicaSecret):
+            raise OperationNotPermittedOnReplica
+
+        if secret.is_deleted():
             raise InvalidRequestException(
                 "An error occurred (InvalidRequestException) when calling the UpdateSecret operation: "
                 "You can't perform this operation on the secret because it was marked for deletion."
             )
 
-        secret = self.secrets[secret_id]
         tags = secret.tags
         description = description or secret.description
 
@@ -415,15 +586,15 @@ class SecretsManagerBackend(BaseBackend):
     def create_secret(
         self,
         name: str,
-        secret_string: Optional[str] = None,
-        secret_binary: Optional[str] = None,
-        description: Optional[str] = None,
-        tags: Optional[List[Dict[str, str]]] = None,
-        kms_key_id: Optional[str] = None,
-        client_request_token: Optional[str] = None,
+        secret_string: Optional[str],
+        secret_binary: Optional[str],
+        description: Optional[str],
+        tags: Optional[List[Dict[str, str]]],
+        kms_key_id: Optional[str],
+        client_request_token: Optional[str],
+        replica_regions: List[Dict[str, str]],
+        force_overwrite: bool,
     ) -> str:
-
-        # error if secret exists
         if name in self.secrets.keys():
             raise ResourceExistsException(
                 "A resource with the ID you requested already exists."
@@ -437,6 +608,8 @@ class SecretsManagerBackend(BaseBackend):
             tags=tags,
             kms_key_id=kms_key_id,
             version_id=client_request_token,
+            replica_regions=replica_regions,
+            force_overwrite=force_overwrite,
         )
 
         return secret.to_short_dict(include_version_id=new_version)
@@ -451,8 +624,9 @@ class SecretsManagerBackend(BaseBackend):
         kms_key_id: Optional[str] = None,
         version_id: Optional[str] = None,
         version_stages: Optional[List[str]] = None,
+        replica_regions: Optional[List[Dict[str, str]]] = None,
+        force_overwrite: bool = False,
     ) -> Tuple[FakeSecret, bool]:
-
         if version_stages is None:
             version_stages = ["AWSCURRENT"]
 
@@ -474,6 +648,8 @@ class SecretsManagerBackend(BaseBackend):
         update_time = int(time.time())
         if secret_id in self.secrets:
             secret = self.secrets[secret_id]
+            if isinstance(secret, ReplicaSecret):
+                raise OperationNotPermittedOnReplica
 
             secret.update(description, tags, kms_key_id, last_changed_date=update_time)
 
@@ -497,11 +673,50 @@ class SecretsManagerBackend(BaseBackend):
                 created_date=update_time,
                 version_id=version_id,
                 secret_version=secret_version,
+                replica_regions=replica_regions,
+                force_overwrite=force_overwrite,
             )
             self.secrets[secret_id] = secret
 
         return secret, new_version
 
+    def create_managed_secret(
+        self,
+        service_name: str,
+        secret_id: str,
+        secret_string: Optional[str] = None,
+        secret_binary: Optional[str] = None,
+        description: Optional[str] = None,
+        tags: Optional[List[Dict[str, str]]] = None,
+        kms_key_id: Optional[str] = None,
+        version_id: Optional[str] = None,
+        replica_regions: Optional[List[Dict[str, str]]] = None,
+        force_overwrite: bool = False,
+    ) -> FakeSecret:
+        """Create an AWS managed secret for the specified service name."""
+        if kms_key_id is None:
+            kms_key_id = self.DEFAULT_KMS_KEY_ALIAS
+        managed_tag = {
+            "Key": "aws:secretsmanager:owningService",
+            "Value": service_name,
+        }
+        if tags is None:
+            tags = [managed_tag]
+        else:
+            tags.append(managed_tag)
+        secret, _ = self._add_secret(
+            secret_id,
+            secret_string=secret_string,
+            secret_binary=secret_binary,
+            description=description,
+            tags=tags,
+            kms_key_id=kms_key_id,
+            version_id=version_id,
+            replica_regions=replica_regions,
+            force_overwrite=force_overwrite,
+        )
+        return secret
+
     def put_secret_value(
         self,
         secret_id: str,
@@ -510,11 +725,12 @@ class SecretsManagerBackend(BaseBackend):
         client_request_token: str,
         version_stages: List[str],
     ) -> str:
-
         if not self._is_valid_identifier(secret_id):
             raise SecretNotFoundException()
         else:
             secret = self.secrets[secret_id]
+            if isinstance(secret, ReplicaSecret):
+                raise OperationNotPermittedOnReplica
             tags = secret.tags
             description = secret.description
 
@@ -532,13 +748,11 @@ class SecretsManagerBackend(BaseBackend):
 
         return secret.to_short_dict(include_version_stages=True, version_id=version_id)
 
-    def describe_secret(self, secret_id: str) -> Dict[str, Any]:
+    def describe_secret(self, secret_id: str) -> Union[FakeSecret, ReplicaSecret]:
         if not self._is_valid_identifier(secret_id):
             raise SecretNotFoundException()
 
-        secret = self.secrets[secret_id]
-
-        return secret.to_dict()
+        return self.secrets[secret_id]
 
     def rotate_secret(
         self,
@@ -546,13 +760,17 @@ class SecretsManagerBackend(BaseBackend):
         client_request_token: Optional[str] = None,
         rotation_lambda_arn: Optional[str] = None,
         rotation_rules: Optional[Dict[str, Any]] = None,
+        rotate_immediately: bool = True,
     ) -> str:
         rotation_days = "AutomaticallyAfterDays"
 
         if not self._is_valid_identifier(secret_id):
             raise SecretNotFoundException()
 
-        if self.secrets[secret_id].is_deleted():
+        secret = self.secrets[secret_id]
+        if isinstance(secret, ReplicaSecret):
+            raise OperationNotPermittedOnReplica
+        if secret.is_deleted():
             raise InvalidRequestException(
                 "An error occurred (InvalidRequestException) when calling the RotateSecret operation: You tried to \
                 perform the operation on a secret that's currently marked deleted."
@@ -560,24 +778,20 @@ class SecretsManagerBackend(BaseBackend):
 
         if rotation_lambda_arn:
             if len(rotation_lambda_arn) > 2048:
-                msg = "RotationLambdaARN " "must <= 2048 characters long."
+                msg = "RotationLambdaARN must <= 2048 characters long."
                 raise InvalidParameterException(msg)
 
         if rotation_rules:
             if rotation_days in rotation_rules:
                 rotation_period = rotation_rules[rotation_days]
                 if rotation_period < 1 or rotation_period > 1000:
-                    msg = (
-                        "RotationRules.AutomaticallyAfterDays " "must be within 1-1000."
-                    )
+                    msg = "RotationRules.AutomaticallyAfterDays must be within 1-1000."
                     raise InvalidParameterException(msg)
 
-                self.secrets[secret_id].next_rotation_date = int(time.time()) + (
+                secret.next_rotation_date = int(time.time()) + (
                     int(rotation_period) * 86400
                 )
 
-        secret = self.secrets[secret_id]
-
         # The rotation function must end with the versions of the secret in
         # one of two states:
         #
@@ -603,30 +817,27 @@ class SecretsManagerBackend(BaseBackend):
             pass
 
         if secret.versions:
-            old_secret_version = secret.versions[secret.default_version_id]  # type: ignore
-
             if client_request_token:
                 self._client_request_token_validator(client_request_token)
                 new_version_id = client_request_token
             else:
                 new_version_id = str(mock_random.uuid4())
 
-            # We add the new secret version as "pending". The previous version remains
-            # as "current" for now. Once we've passed the new secret through the lambda
-            # rotation function (if provided) we can then update the status to "current".
-            old_secret_version_secret_string = (
-                old_secret_version["secret_string"]
-                if "secret_string" in old_secret_version
-                else None
-            )
-            self._add_secret(
-                secret_id,
-                old_secret_version_secret_string,
-                description=secret.description,
-                tags=secret.tags,
-                version_id=new_version_id,
-                version_stages=["AWSPENDING"],
-            )
+            # We add a "pending" stage. The previous version remains as "current" for now.
+            # Caller is responsible for creating the new secret in the Lambda
+            secret_version = {
+                "createdate": int(time.time()),
+                "version_id": new_version_id,
+                "version_stages": ["AWSPENDING"],
+            }
+            if not rotate_immediately:
+                if secret.secret_string is not None:
+                    secret_version["secret_string"] = secret.secret_string
+                if secret.secret_binary is not None:
+                    secret_version["secret_binary"] = secret.secret_binary
+
+            secret.remove_version_stages_from_old_versions(["AWSPENDING"])
+            secret.versions[new_version_id] = secret_version
 
         secret.rotation_requested = True
         secret.rotation_lambda_arn = rotation_lambda_arn or ""
@@ -637,33 +848,43 @@ class SecretsManagerBackend(BaseBackend):
 
         # Begin the rotation process for the given secret by invoking the lambda function.
         if secret.rotation_lambda_arn:
-            from moto.awslambda.models import lambda_backends
+            from moto.awslambda.utils import get_backend
 
-            lambda_backend = lambda_backends[self.account_id][self.region_name]
+            lambda_backend = get_backend(self.account_id, self.region_name)
 
             request_headers: Dict[str, Any] = {}
             response_headers: Dict[str, Any] = {}
 
             try:
-                func = lambda_backend.get_function(secret.rotation_lambda_arn)
+                lambda_backend.get_function(secret.rotation_lambda_arn)
             except Exception:
                 msg = f"Resource not found for ARN '{secret.rotation_lambda_arn}'."
                 raise ResourceNotFoundException(msg)
 
-            for step in ["create", "set", "test", "finish"]:
-                func.invoke(
-                    json.dumps(
+            rotation_steps = ["create", "set", "test", "finish"]
+            if not rotate_immediately:
+                # if you don't immediately rotate the secret,
+                # Secrets Manager tests the rotation configuration by running the testSecretstep of the Lambda rotation function.
+                rotation_steps = ["test"]
+            for step in rotation_steps:
+                lambda_backend.invoke(
+                    secret.rotation_lambda_arn,
+                    qualifier=None,
+                    body=json.dumps(
                         {
                             "Step": step + "Secret",
                             "SecretId": secret.name,
                             "ClientRequestToken": new_version_id,
                         }
                     ),
-                    request_headers,
-                    response_headers,
+                    headers=request_headers,
+                    response_headers=response_headers,
                 )
+            if rotate_immediately:
+                # If we don't rotate, we only invoke the testSecret step
+                # This should be done with the existing (old) version ID
+                secret.set_default_version_id(new_version_id)
 
-            secret.set_default_version_id(new_version_id)
         elif secret.versions:
             # AWS will always require a Lambda ARN
             # without that, Moto can still apply the 'AWSCURRENT'-label
@@ -673,7 +894,7 @@ class SecretsManagerBackend(BaseBackend):
             )
             secret.versions[new_version_id]["version_stages"] = ["AWSCURRENT"]
 
-        self.secrets[secret_id].last_rotation_date = int(time.time())
+        secret.last_rotation_date = int(time.time())
         return secret.to_short_dict()
 
     def get_random_password(
@@ -741,28 +962,28 @@ class SecretsManagerBackend(BaseBackend):
     def list_secrets(
         self,
         filters: List[Dict[str, Any]],
-        max_results: int = 100,
+        max_results: int = MAX_RESULTS_DEFAULT,
         next_token: Optional[str] = None,
+        include_planned_deletion: bool = False,
     ) -> Tuple[List[Dict[str, Any]], Optional[str]]:
-        secret_list = []
+        secret_list: List[Dict[str, Any]] = []
         for secret in self.secrets.values():
+            if hasattr(secret, "deleted_date"):
+                if secret.deleted_date and not include_planned_deletion:
+                    continue
             if _matches(secret, filters):
                 secret_list.append(secret.to_dict())
 
-        starting_point = int(next_token or 0)
-        ending_point = starting_point + int(max_results or 100)
-        secret_page = secret_list[starting_point:ending_point]
-        new_next_token = str(ending_point) if ending_point < len(secret_list) else None
-
-        return secret_page, new_next_token
+        return self._get_secret_values_page_and_next_token(
+            secret_list, max_results, next_token
+        )
 
     def delete_secret(
         self,
         secret_id: str,
-        recovery_window_in_days: int,
+        recovery_window_in_days: Optional[int],
         force_delete_without_recovery: bool,
     ) -> Tuple[str, str, float]:
-
         if recovery_window_in_days is not None and (
             recovery_window_in_days < 7 or recovery_window_in_days > 30
         ):
@@ -781,12 +1002,22 @@ class SecretsManagerBackend(BaseBackend):
             if not force_delete_without_recovery:
                 raise SecretNotFoundException()
             else:
-                arn = secret_arn(self.account_id, self.region_name, secret_id=secret_id)
+                arn = SecretsManagerSecretIdentifier(
+                    self.account_id, self.region_name, secret_id=secret_id
+                ).generate()
                 name = secret_id
                 deletion_date = utcnow()
                 return arn, name, self._unix_time_secs(deletion_date)
         else:
-            if self.secrets[secret_id].is_deleted():
+            secret = self.secrets[secret_id]
+            if isinstance(secret, ReplicaSecret):
+                raise OperationNotPermittedOnReplica
+            if len(secret.replicas) > 0:
+                replica_regions = ",".join([rep.region for rep in secret.replicas])
+                msg = f"You can't delete secret {secret_id} that still has replica regions [{replica_regions}]"
+                raise InvalidParameterException(msg)
+
+            if secret.is_deleted() and not force_delete_without_recovery:
                 raise InvalidRequestException(
                     "An error occurred (InvalidRequestException) when calling the DeleteSecret operation: You tried to \
                     perform the operation on a secret that's currently marked deleted."
@@ -795,11 +1026,10 @@ class SecretsManagerBackend(BaseBackend):
             deletion_date = utcnow()
 
             if force_delete_without_recovery:
-                secret = self.secrets.pop(secret_id)
+                self.secrets.pop(secret_id)
             else:
                 deletion_date += datetime.timedelta(days=recovery_window_in_days or 30)
-                self.secrets[secret_id].delete(self._unix_time_secs(deletion_date))
-                secret = self.secrets.get(secret_id)
+                secret.delete(self._unix_time_secs(deletion_date))
 
             if not secret:
                 raise SecretNotFoundException()
@@ -810,47 +1040,43 @@ class SecretsManagerBackend(BaseBackend):
             return arn, name, self._unix_time_secs(deletion_date)
 
     def restore_secret(self, secret_id: str) -> Tuple[str, str]:
-
         if not self._is_valid_identifier(secret_id):
             raise SecretNotFoundException()
 
         secret = self.secrets[secret_id]
+        if isinstance(secret, ReplicaSecret):
+            raise OperationNotPermittedOnReplica
         secret.restore()
 
         return secret.arn, secret.name
 
     def tag_resource(self, secret_id: str, tags: List[Dict[str, str]]) -> None:
-
         if secret_id not in self.secrets:
             raise SecretNotFoundException()
 
         secret = self.secrets[secret_id]
-        old_tags = secret.tags
+        if isinstance(secret, ReplicaSecret):
+            raise OperationNotPermittedOnReplica
+
+        old_tags = {tag["Key"]: tag for tag in secret.tags or []}
 
         for tag in tags:
-            existing_key_name = next(
-                (
-                    old_key
-                    for old_key in old_tags
-                    if old_key.get("Key") == tag.get("Key")
-                ),
-                None,
-            )
-            if existing_key_name:
-                old_tags.remove(existing_key_name)
-            old_tags.append(tag)
+            old_tags[tag["Key"]] = tag
+
+        secret.tags = list(old_tags.values())
 
     def untag_resource(self, secret_id: str, tag_keys: List[str]) -> None:
-
         if secret_id not in self.secrets:
             raise SecretNotFoundException()
 
         secret = self.secrets[secret_id]
-        tags = secret.tags
+        if isinstance(secret, ReplicaSecret):
+            raise OperationNotPermittedOnReplica
 
-        for tag in tags:
-            if tag["Key"] in tag_keys:
-                tags.remove(tag)
+        if secret.tags is None:
+            return
+
+        secret.tags = [tag for tag in secret.tags if tag["Key"] not in tag_keys]
 
     def update_secret_version_stage(
         self,
@@ -877,6 +1103,14 @@ class SecretsManagerBackend(BaseBackend):
                 )
 
             stages.remove(version_stage)
+        elif version_stage == "AWSCURRENT":
+            current_version = [
+                v
+                for v in secret.versions
+                if "AWSCURRENT" in secret.versions[v]["version_stages"]
+            ][0]
+            err = f"The parameter RemoveFromVersionId can't be empty. Staging label AWSCURRENT is currently attached to version {current_version}, so you must explicitly reference that version in RemoveFromVersionId."
+            raise InvalidParameterException(err)
 
         if move_to_version_id:
             if move_to_version_id not in secret.versions:
@@ -892,6 +1126,9 @@ class SecretsManagerBackend(BaseBackend):
                 # Whenever you move AWSCURRENT, Secrets Manager automatically
                 # moves the label AWSPREVIOUS to the version that AWSCURRENT
                 # was removed from.
+                for version in secret.versions:
+                    if "AWSPREVIOUS" in secret.versions[version]["version_stages"]:
+                        secret.versions[version]["version_stages"].remove("AWSPREVIOUS")
                 secret.versions[remove_from_version_id]["version_stages"].append(
                     "AWSPREVIOUS"
                 )
@@ -911,6 +1148,8 @@ class SecretsManagerBackend(BaseBackend):
             raise SecretNotFoundException()
 
         secret = self.secrets[secret_id]
+        if isinstance(secret, ReplicaSecret):
+            raise OperationNotPermittedOnReplica
         secret.policy = policy
         return secret.arn, secret.name
 
@@ -919,6 +1158,8 @@ class SecretsManagerBackend(BaseBackend):
             raise SecretNotFoundException()
 
         secret = self.secrets[secret_id]
+        if isinstance(secret, ReplicaSecret):
+            raise OperationNotPermittedOnReplica
         resp = {
             "ARN": secret.arn,
             "Name": secret.name,
@@ -932,8 +1173,54 @@ class SecretsManagerBackend(BaseBackend):
             raise SecretNotFoundException()
 
         secret = self.secrets[secret_id]
+        if isinstance(secret, ReplicaSecret):
+            raise OperationNotPermittedOnReplica
         secret.policy = None
         return secret.arn, secret.name
 
+    def replicate_secret_to_regions(
+        self,
+        secret_id: str,
+        replica_regions: List[Dict[str, str]],
+        force_overwrite: bool,
+    ) -> Tuple[str, List[Dict[str, Any]]]:
+        secret = self.describe_secret(secret_id)
+        if isinstance(secret, ReplicaSecret):
+            raise OperationNotPermittedOnReplica
+        secret.replicas.extend(
+            secret.create_replicas(replica_regions, force_overwrite=force_overwrite)
+        )
+        statuses = [replica.config for replica in secret.replicas]
+        return secret_id, statuses
+
+    def remove_regions_from_replication(
+        self, secret_id: str, replica_regions: List[str]
+    ) -> Tuple[str, List[Dict[str, str]]]:
+        secret = self.describe_secret(secret_id)
+        if isinstance(secret, ReplicaSecret):
+            raise OperationNotPermittedOnReplica
+        for replica in secret.replicas.copy():
+            if replica.region in replica_regions:
+                backend = secretsmanager_backends[self.account_id][replica.region]
+                if replica.has_replica:
+                    dict.pop(backend.secrets, replica.arn)
+                secret.replicas.remove(replica)
+
+        statuses = [replica.config for replica in secret.replicas]
+        return secret_id, statuses
+
+    def _get_secret_values_page_and_next_token(
+        self,
+        secret_list: List[Dict[str, Any]],
+        max_results: Optional[int],
+        next_token: Optional[str],
+    ) -> Tuple[List[Dict[str, Any]], Optional[str]]:
+        starting_point = int(next_token or 0)
+        ending_point = starting_point + int(max_results or MAX_RESULTS_DEFAULT)
+        secret_page = secret_list[starting_point:ending_point]
+        new_next_token = str(ending_point) if ending_point < len(secret_list) else None
+
+        return secret_page, new_next_token
+
 
 secretsmanager_backends = BackendDict(SecretsManagerBackend, "secretsmanager")
