@@ -1,12 +1,14 @@
+import copy
+
 import boto3
 
-from moto import mock_autoscaling, mock_ec2
-
-from .utils import setup_networking
+from moto import mock_aws
 from tests import EXAMPLE_AMI_ID
 
+from .utils import setup_networking
 
-@mock_autoscaling
+
+@mock_aws
 def test_autoscaling_tags_update():
     mocked_networking = setup_networking()
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -50,11 +52,10 @@ def test_autoscaling_tags_update():
     )
 
     response = client.describe_auto_scaling_groups(AutoScalingGroupNames=["test_asg"])
-    response["AutoScalingGroups"][0]["Tags"].should.have.length_of(2)
+    assert len(response["AutoScalingGroups"][0]["Tags"]) == 2
 
 
-@mock_autoscaling
-@mock_ec2
+@mock_aws
 def test_delete_tags_by_key():
     mocked_networking = setup_networking()
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -101,65 +102,57 @@ def test_delete_tags_by_key():
     )
     group = response["AutoScalingGroups"][0]
     tags = group["Tags"]
-    tags.should.contain(tag_to_keep)
-    tags.should_not.contain(tag_to_delete)
+    assert tag_to_keep in tags
+    assert tag_to_delete not in tags
 
 
-@mock_autoscaling
+@mock_aws
 def test_describe_tags_without_resources():
     client = boto3.client("autoscaling", region_name="us-east-2")
     resp = client.describe_tags()
-    resp.should.have.key("Tags").equals([])
-    resp.shouldnt.have.key("NextToken")
+    assert resp["Tags"] == []
+    assert "NextToken" not in resp
 
 
-@mock_autoscaling
+@mock_aws
 def test_describe_tags_no_filter():
     subnet = setup_networking()["subnet1"]
     client = boto3.client("autoscaling", region_name="us-east-1")
     create_asgs(client, subnet)
 
     response = client.describe_tags()
-    response.should.have.key("Tags").length_of(4)
-    response["Tags"].should.contain(
-        {
-            "ResourceId": "test_asg",
-            "ResourceType": "auto-scaling-group",
-            "Key": "test_key",
-            "Value": "updated_test_value",
-            "PropagateAtLaunch": True,
-        }
-    )
-    response["Tags"].should.contain(
-        {
-            "ResourceId": "test_asg",
-            "ResourceType": "auto-scaling-group",
-            "Key": "test_key2",
-            "Value": "test_value2",
-            "PropagateAtLaunch": False,
-        }
-    )
-    response["Tags"].should.contain(
-        {
-            "ResourceId": "test_asg2",
-            "ResourceType": "auto-scaling-group",
-            "Key": "asg2tag1",
-            "Value": "val",
-            "PropagateAtLaunch": False,
-        }
-    )
-    response["Tags"].should.contain(
-        {
-            "ResourceId": "test_asg2",
-            "ResourceType": "auto-scaling-group",
-            "Key": "asg2tag2",
-            "Value": "diff",
-            "PropagateAtLaunch": False,
-        }
-    )
+    len(response["Tags"]) == 4
+    assert {
+        "ResourceId": "test_asg",
+        "ResourceType": "auto-scaling-group",
+        "Key": "test_key",
+        "Value": "updated_test_value",
+        "PropagateAtLaunch": True,
+    } in response["Tags"]
+    assert {
+        "ResourceId": "test_asg",
+        "ResourceType": "auto-scaling-group",
+        "Key": "test_key2",
+        "Value": "test_value2",
+        "PropagateAtLaunch": False,
+    } in response["Tags"]
+    assert {
+        "ResourceId": "test_asg2",
+        "ResourceType": "auto-scaling-group",
+        "Key": "asg2tag1",
+        "Value": "val",
+        "PropagateAtLaunch": False,
+    } in response["Tags"]
+    assert {
+        "ResourceId": "test_asg2",
+        "ResourceType": "auto-scaling-group",
+        "Key": "asg2tag2",
+        "Value": "diff",
+        "PropagateAtLaunch": False,
+    } in response["Tags"]
 
 
-@mock_autoscaling
+@mock_aws
 def test_describe_tags_filter_by_name():
     subnet = setup_networking()["subnet1"]
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -168,69 +161,57 @@ def test_describe_tags_filter_by_name():
     response = client.describe_tags(
         Filters=[{"Name": "auto-scaling-group", "Values": ["test_asg"]}]
     )
-    response.should.have.key("Tags").length_of(2)
-    response["Tags"].should.contain(
-        {
-            "ResourceId": "test_asg",
-            "ResourceType": "auto-scaling-group",
-            "Key": "test_key",
-            "Value": "updated_test_value",
-            "PropagateAtLaunch": True,
-        }
-    )
-    response["Tags"].should.contain(
-        {
-            "ResourceId": "test_asg",
-            "ResourceType": "auto-scaling-group",
-            "Key": "test_key2",
-            "Value": "test_value2",
-            "PropagateAtLaunch": False,
-        }
-    )
+    assert len(response["Tags"]) == 2
+    assert {
+        "ResourceId": "test_asg",
+        "ResourceType": "auto-scaling-group",
+        "Key": "test_key",
+        "Value": "updated_test_value",
+        "PropagateAtLaunch": True,
+    } in response["Tags"]
+    assert {
+        "ResourceId": "test_asg",
+        "ResourceType": "auto-scaling-group",
+        "Key": "test_key2",
+        "Value": "test_value2",
+        "PropagateAtLaunch": False,
+    } in response["Tags"]
 
     response = client.describe_tags(
         Filters=[{"Name": "auto-scaling-group", "Values": ["test_asg", "test_asg2"]}]
     )
-    response.should.have.key("Tags").length_of(4)
-    response["Tags"].should.contain(
-        {
-            "ResourceId": "test_asg",
-            "ResourceType": "auto-scaling-group",
-            "Key": "test_key",
-            "Value": "updated_test_value",
-            "PropagateAtLaunch": True,
-        }
-    )
-    response["Tags"].should.contain(
-        {
-            "ResourceId": "test_asg",
-            "ResourceType": "auto-scaling-group",
-            "Key": "test_key2",
-            "Value": "test_value2",
-            "PropagateAtLaunch": False,
-        }
-    )
-    response["Tags"].should.contain(
-        {
-            "ResourceId": "test_asg2",
-            "ResourceType": "auto-scaling-group",
-            "Key": "asg2tag1",
-            "Value": "val",
-            "PropagateAtLaunch": False,
-        }
-    )
-    response["Tags"].should.contain(
-        {
-            "ResourceId": "test_asg2",
-            "ResourceType": "auto-scaling-group",
-            "Key": "asg2tag2",
-            "Value": "diff",
-            "PropagateAtLaunch": False,
-        }
-    )
+    assert len(response["Tags"]) == 4
+    assert {
+        "ResourceId": "test_asg",
+        "ResourceType": "auto-scaling-group",
+        "Key": "test_key",
+        "Value": "updated_test_value",
+        "PropagateAtLaunch": True,
+    } in response["Tags"]
+    assert {
+        "ResourceId": "test_asg",
+        "ResourceType": "auto-scaling-group",
+        "Key": "test_key2",
+        "Value": "test_value2",
+        "PropagateAtLaunch": False,
+    } in response["Tags"]
+    assert {
+        "ResourceId": "test_asg2",
+        "ResourceType": "auto-scaling-group",
+        "Key": "asg2tag1",
+        "Value": "val",
+        "PropagateAtLaunch": False,
+    } in response["Tags"]
+    assert {
+        "ResourceId": "test_asg2",
+        "ResourceType": "auto-scaling-group",
+        "Key": "asg2tag2",
+        "Value": "diff",
+        "PropagateAtLaunch": False,
+    } in response["Tags"]
 
 
-@mock_autoscaling
+@mock_aws
 def test_describe_tags_filter_by_propgateatlaunch():
     subnet = setup_networking()["subnet1"]
     client = boto3.client("autoscaling", region_name="us-east-1")
@@ -239,8 +220,8 @@ def test_describe_tags_filter_by_propgateatlaunch():
     response = client.describe_tags(
         Filters=[{"Name": "propagate-at-launch", "Values": ["True"]}]
     )
-    response.should.have.key("Tags").length_of(1)
-    response["Tags"].should.contain(
+    len(response["Tags"]) == 1
+    assert response["Tags"] == [
         {
             "ResourceId": "test_asg",
             "ResourceType": "auto-scaling-group",
@@ -248,6 +229,72 @@ def test_describe_tags_filter_by_propgateatlaunch():
             "Value": "updated_test_value",
             "PropagateAtLaunch": True,
         }
+    ]
+
+
+@mock_aws
+def test_describe_tags_filter_by_key_or_value():
+    subnet = setup_networking()["subnet1"]
+    client = boto3.client("autoscaling", region_name="us-east-1")
+    create_asgs(client, subnet)
+
+    tags = client.describe_tags(Filters=[{"Name": "key", "Values": ["test_key"]}])[
+        "Tags"
+    ]
+    assert tags == [
+        {
+            "ResourceId": "test_asg",
+            "ResourceType": "auto-scaling-group",
+            "Key": "test_key",
+            "Value": "updated_test_value",
+            "PropagateAtLaunch": True,
+        }
+    ]
+
+    tags = client.describe_tags(Filters=[{"Name": "value", "Values": ["test_value2"]}])[
+        "Tags"
+    ]
+    assert tags == [
+        {
+            "ResourceId": "test_asg",
+            "ResourceType": "auto-scaling-group",
+            "Key": "test_key2",
+            "Value": "test_value2",
+            "PropagateAtLaunch": False,
+        }
+    ]
+
+
+@mock_aws
+def test_create_20_tags_auto_scaling_group():
+    """test to verify that the tag-members are sorted correctly, and there is no regression for
+    https://github.com/getmoto/moto/issues/6033
+    """
+    subnet = setup_networking()["subnet1"]
+    client = boto3.client("autoscaling", region_name="us-east-1")
+    original = {
+        "ResourceId": "test_asg",
+        "PropagateAtLaunch": True,
+    }
+    tags = []
+    for i in range(0, 20):
+        cp = copy.deepcopy(original)
+        cp["Key"] = f"test_key{i}"
+        cp["Value"] = f"random-value-{i}"
+        tags.append(cp)
+    client.create_launch_configuration(
+        LaunchConfigurationName="test_launch_configuration",
+        ImageId=EXAMPLE_AMI_ID,
+        InstanceType="t2.medium",
+    )
+    client.create_auto_scaling_group(
+        AutoScalingGroupName="test_asg",
+        LaunchConfigurationName="test_launch_configuration",
+        MinSize=0,
+        MaxSize=20,
+        DesiredCapacity=5,
+        Tags=tags,
+        VPCZoneIdentifier=subnet,
     )
 
 
