@@ -1,5 +1,4 @@
 import json
-import sure  # noqa # pylint: disable=unused-import
 
 from moto.awslambda.policy import Policy
 
@@ -37,11 +36,11 @@ def test_policy():
     }
 
     policy.add_statement(json.dumps(statement))
-    expected.should.be.equal(policy.statements[0])
+    assert expected == policy.statements[0]
 
     sid = statement.get("StatementId", None)
     if sid is None:
         raise "TestCase.statement does not contain StatementId"
 
     policy.del_statement(sid)
-    [].should.be.equal(policy.statements)
+    assert [] == policy.statements
