@@ -194,8 +194,9 @@ def test_describe_cluster_not_found():
     conn = boto3.client("emr", region_name="us-east-1")
     with pytest.raises(ClientError) as e:
         conn.describe_cluster(ClusterId="DummyId")
-
-    assert e.value.response["Error"]["Code"] == "ResourceNotFoundException"
+    resp = e.value.response
+    assert resp["Error"]["Code"] == "InvalidRequestException"
+    assert resp["ErrorCode"] == "NoSuchCluster"
 
 
 @mock_aws
@@ -1125,19 +1126,21 @@ def test_security_configurations():
 
     with pytest.raises(ClientError) as ex:
         client.describe_security_configuration(Name=security_configuration_name)
-    err = ex.value.response["Error"]
-    assert err["Code"] == "InvalidRequestException"
+    resp = ex.value.response
+    assert resp["Error"]["Code"] == "InvalidRequestException"
+    assert resp["ErrorCode"] == "ResourceNotFound"
     assert (
-        err["Message"]
+        resp["Error"]["Message"]
         == "Security configuration with name 'MySecurityConfiguration' does not exist."
     )
 
     with pytest.raises(ClientError) as ex:
         client.delete_security_configuration(Name=security_configuration_name)
-    err = ex.value.response["Error"]
-    assert err["Code"] == "InvalidRequestException"
+    resp = ex.value.response
+    assert resp["Error"]["Code"] == "InvalidRequestException"
+    assert resp["ErrorCode"] == "ResourceNotFound"
     assert (
-        err["Message"]
+        resp["Error"]["Message"]
         == "Security configuration with name 'MySecurityConfiguration' does not exist."
     )
 
