@@ -1,17 +1,18 @@
+import contextlib
 import json
 import os
 from datetime import datetime
 from unittest import SkipTest, mock
 
 import boto3
+import pytest
 
-from moto import mock_events, mock_logs, mock_sqs, settings
+from moto import mock_aws, settings
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from moto.core.utils import iso_8601_datetime_without_milliseconds, utcnow
 
 
-@mock_events
-@mock_logs
+@mock_aws
 def test_send_to_cw_log_group():
     # given
     client_events = boto3.client("events", "eu-central-1")
@@ -67,8 +68,7 @@ def test_send_to_cw_log_group():
     assert message["detail"] == {"key": "value"}
 
 
-@mock_events
-@mock_sqs
+@mock_aws
 def test_send_to_sqs_fifo_queue():
     # given
     client_events = boto3.client("events", "eu-central-1")
@@ -112,16 +112,23 @@ def test_send_to_sqs_fifo_queue():
 
     # when
     event_time = datetime(2021, 1, 1, 12, 23, 34)
-    client_events.put_events(
-        Entries=[
-            {
-                "Time": event_time,
-                "Source": "source",
-                "DetailType": "type",
-                "Detail": json.dumps({"key": "value"}),
-            }
-        ]
+    # Catch and validate a UserWarning when running locally.
+    context = (
+        pytest.warns(UserWarning, match="you must enable content-based deduplication")
+        if not settings.TEST_SERVER_MODE
+        else contextlib.nullcontext()
     )
+    with context:
+        client_events.put_events(
+            Entries=[
+                {
+                    "Time": event_time,
+                    "Source": "source",
+                    "DetailType": "type",
+                    "Detail": json.dumps({"key": "value"}),
+                }
+            ]
+        )
 
     # then
     response = client_sqs.receive_message(
@@ -155,8 +162,7 @@ def test_send_to_sqs_fifo_queue():
     assert "Messages" not in response
 
 
-@mock_events
-@mock_sqs
+@mock_aws
 def test_send_to_sqs_queue():
     # given
     client_events = boto3.client("events", "eu-central-1")
@@ -205,8 +211,7 @@ def test_send_to_sqs_queue():
     assert body["detail"] == {"key": "value"}
 
 
-@mock_events
-@mock_sqs
+@mock_aws
 def test_send_to_sqs_queue_with_custom_event_bus():
     # given
     client_events = boto3.client("events", "eu-central-1")
@@ -250,8 +255,7 @@ def test_send_to_sqs_queue_with_custom_event_bus():
     assert body["detail"] == {"key": "value"}
 
 
-@mock_events
-@mock_logs
+@mock_aws
 def test_moto_matches_none_value_with_exists_filter():
     pattern = {
         "source": ["test-source"],
@@ -317,8 +321,7 @@ def test_moto_matches_none_value_with_exists_filter():
     ]
 
 
-@mock_events
-@mock_sqs
+@mock_aws
 def test_put_events_event_bus_forwarding_rules():
     if settings.TEST_SERVER_MODE:
         raise SkipTest("Cross-account test - easiest to just test in DecoratorMode")
