@@ -1,10 +1,10 @@
 import json
 
 import moto.server as server
-from moto import mock_kinesis
+from moto import mock_aws
 
 
-@mock_kinesis
+@mock_aws
 def test_list_streams():
     backend = server.create_backend_app("kinesis")
     test_client = backend.test_client()
@@ -12,4 +12,8 @@ def test_list_streams():
     res = test_client.get("/?Action=ListStreams")
 
     json_data = json.loads(res.data.decode("utf-8"))
-    assert json_data == {"HasMoreStreams": False, "StreamNames": []}
+    assert json_data == {
+        "HasMoreStreams": False,
+        "StreamNames": [],
+        "StreamSummaries": [],
+    }
