@@ -970,6 +970,99 @@ def test_get_resources_lambda():
     assert_response(resp, [rectangle_arn])
 
 
+@mock_aws
+def test_tag_resources_lambda():
+    client = boto3.client("lambda", region_name="us-west-2")
+    rtapi = boto3.client("resourcegroupstaggingapi", region_name="us-west-2")
+
+    def get_role_name():
+        iam = boto3.client("iam", region_name="us-west-2")
+        try:
+            return iam.get_role(RoleName="my-role")["Role"]["Arn"]
+        except ClientError:
+            return iam.create_role(
+                RoleName="my-role",
+                AssumeRolePolicyDocument="some policy",
+                Path="/my-path/",
+            )["Role"]["Arn"]
+
+    zipfile = """
+              def lambda_handler(event, context):
+                  print("custom log event")
+                  return event
+              """
+
+    func = client.create_function(
+        FunctionName="lambda-tag-resource-test",
+        Runtime="python3.13",
+        Role=get_role_name(),
+        Handler="lambda_function.lambda_handler",
+        Code={"ZipFile": zipfile},
+        Description="test lambda function",
+        Timeout=3,
+        MemorySize=128,
+        Publish=True,
+        Tags={"tag": "a"},
+    )
+
+    rtapi.tag_resources(
+        ResourceARNList=[func["FunctionArn"]], Tags={"secondtag": "b", "thirdtag": "c"}
+    )
+
+    resp = client.list_tags(Resource=func["FunctionArn"])
+
+    assert resp["Tags"]["tag"] == "a"
+    assert resp["Tags"]["secondtag"] == "b"
+    assert resp["Tags"]["thirdtag"] == "c"
+
+
+@mock_aws
+def test_untag_resources_lambda():
+    client = boto3.client("lambda", region_name="us-west-2")
+    rtapi = boto3.client("resourcegroupstaggingapi", region_name="us-west-2")
+
+    def get_role_name():
+        iam = boto3.client("iam", region_name="us-west-2")
+        try:
+            return iam.get_role(RoleName="my-role")["Role"]["Arn"]
+        except ClientError:
+            return iam.create_role(
+                RoleName="my-role",
+                AssumeRolePolicyDocument="some policy",
+                Path="/my-path/",
+            )["Role"]["Arn"]
+
+    zipfile = """
+              def lambda_handler(event, context):
+                  print("custom log event")
+                  return event
+              """
+
+    func = client.create_function(
+        FunctionName="lambda-tag-resource-test",
+        Runtime="python3.13",
+        Role=get_role_name(),
+        Handler="lambda_function.lambda_handler",
+        Code={"ZipFile": zipfile},
+        Description="test lambda function",
+        Timeout=3,
+        MemorySize=128,
+        Publish=True,
+        Tags={"tag": "a", "secondtag": "b", "thirdtag": "c"},
+    )
+
+    rtapi.untag_resources(
+        ResourceARNList=[func["FunctionArn"]], TagKeys=["tag", "secondtag"]
+    )
+
+    resp = client.list_tags(Resource=func["FunctionArn"])
+
+    assert len(resp["Tags"]) == 1
+    assert "tag" not in resp["Tags"]
+    assert "secondtag" not in resp["Tags"]
+    assert "thirdtag" in resp["Tags"]
+
+
 @mock_aws
 def test_get_resources_sqs():
     sqs = boto3.resource("sqs", region_name="eu-central-1")
@@ -1174,6 +1267,20 @@ def test_tag_resources_for_unknown_service():
     )
 
 
+@mock_aws
+def test_untag_resources_for_unknown_service():
+    rtapi = boto3.client("resourcegroupstaggingapi", region_name="us-west-2")
+    missing_resources = rtapi.untag_resources(
+        ResourceARNList=["arn:aws:service_x"], TagKeys=["key1", "key2"]
+    )["FailedResourcesMap"]
+
+    assert "arn:aws:service_x" in missing_resources
+    assert (
+        missing_resources["arn:aws:service_x"]["ErrorCode"]
+        == "InternalServiceException"
+    )
+
+
 @mock_aws
 def test_get_resources_elb():
     client = boto3.client("elb", region_name="us-east-1")
@@ -1407,6 +1514,90 @@ def test_get_resources_efs():
     assert ap_two["AccessPointArn"] in returned_arns
 
 
+@mock_aws
+def test_tag_resources_efs():
+    efs = boto3.client("efs", region_name="us-east-1")
+    rtapi = boto3.client("resourcegroupstaggingapi", region_name="us-east-1")
+
+    fs = efs.create_file_system(
+        CreationToken="test-token-1", Tags=[{"Key": "tag", "Value": "a"}]
+    )
+
+    ap = efs.create_access_point(
+        ClientToken="ct-1",
+        FileSystemId=fs["FileSystemId"],
+        Tags=[{"Key": "aptag", "Value": "ap-a"}],
+    )
+
+    rtapi.tag_resources(
+        ResourceARNList=[fs["FileSystemArn"]], Tags={"secondtag": "b", "thirdtag": "c"}
+    )
+
+    rtapi.tag_resources(
+        ResourceARNList=[ap["AccessPointArn"]],
+        Tags={"apsecondtag": "ap-b", "apthirdtag": "ap-c"},
+    )
+
+    resp = efs.list_tags_for_resource(ResourceId=fs["FileSystemId"])
+
+    assert {"Key": "tag", "Value": "a"} in resp["Tags"]
+    assert {"Key": "secondtag", "Value": "b"} in resp["Tags"]
+    assert {"Key": "thirdtag", "Value": "c"} in resp["Tags"]
+
+    resp = efs.list_tags_for_resource(ResourceId=ap["AccessPointId"])
+
+    assert {"Key": "aptag", "Value": "ap-a"} in resp["Tags"]
+    assert {"Key": "apsecondtag", "Value": "ap-b"} in resp["Tags"]
+    assert {"Key": "apthirdtag", "Value": "ap-c"} in resp["Tags"]
+
+
+@mock_aws
+def test_untag_resources_efs():
+    efs = boto3.client("efs", region_name="us-east-1")
+    rtapi = boto3.client("resourcegroupstaggingapi", region_name="us-east-1")
+
+    fs = efs.create_file_system(
+        CreationToken="test-token-1",
+        Tags=[
+            {"Key": "tag", "Value": "a"},
+            {"Key": "secondtag", "Value": "b"},
+            {"Key": "thirdtag", "Value": "c"},
+        ],
+    )
+
+    ap = efs.create_access_point(
+        ClientToken="ct-1",
+        FileSystemId=fs["FileSystemId"],
+        Tags=[
+            {"Key": "aptag", "Value": "ap-a"},
+            {"Key": "apsecondtag", "Value": "ap-b"},
+            {"Key": "apthirdtag", "Value": "ap-c"},
+        ],
+    )
+
+    rtapi.untag_resources(
+        ResourceARNList=[fs["FileSystemArn"]], TagKeys=["tag", "secondtag"]
+    )
+
+    rtapi.untag_resources(
+        ResourceARNList=[ap["AccessPointArn"]], TagKeys=["apthirdtag"]
+    )
+
+    resp = efs.list_tags_for_resource(ResourceId=fs["FileSystemId"])
+
+    assert len(resp["Tags"]) == 1
+    assert {"Key": "tag", "Value": "a"} not in resp["Tags"]
+    assert {"Key": "secondtag", "Value": "b"} not in resp["Tags"]
+    assert {"Key": "thirdtag", "Value": "c"} in resp["Tags"]
+
+    resp = efs.list_tags_for_resource(ResourceId=ap["AccessPointId"])
+
+    assert len(resp["Tags"]) == 2
+    assert {"Key": "aptag", "Value": "ap-a"} in resp["Tags"]
+    assert {"Key": "apsecondtag", "Value": "ap-b"} in resp["Tags"]
+    assert {"Key": "apthirdtag", "Value": "ap-c"} not in resp["Tags"]
+
+
 @mock_aws
 def test_get_resources_stepfunction():
     simple_definition = (
